from math import *

def find_stronghold(x0, z0, theta0, x1, z1, theta1):
    """Triangulates the position of a stronghold given two position and direction fixes.
Returns None if triangulation fails."""
    # Convert Minecraft X/Y/Z coordinates into Cartesian (x,y) coordinates.
    # Note that if you're already in standard Cartesian coordinates, the sign changing and angle munging should be removed.
    y0 = -z0
    y1 = -z1
    # Convert Minecraft angles into standard angles.
    theta0 = radians(270 - theta0)
    theta1 = radians(270 - theta1)
    # Check if rays are parallel.
    sine = sin(theta0 - theta1)
    if sine == 0:
        print('Rays are parallel. Cannot triangulate.')
        return None
    if fabs(sine) < 0.1:
        print('Angle between rays is tiny. Expect large error in triangulated position.')
    # Compute intersection.
    t = (sin(theta1) * (x0 - x1) - cos(theta1) * (y0 - y1)) / sine
    x = x0 + t * cos(theta0)
    # Note that the sign gets flipped again here to convert back to Minecraft's X/Y/Z system.
    z = -y0 - t * sin(theta0)
    # Check if intersection is real.
    t1 = (x - x1) / cos(theta1)
    if t < 0 or t1 < 0:
        print('Rays do not point to a common point.')
        return None
    return (x, z)
